import unittest
from asciimatics.event import MouseEvent
from asciimatics.paths import Path, DynamicPath


class TestPaths(unittest.TestCase):
    def assert_path_equals(self, path, oracle):
        path.reset()
        positions = []
        while not path.is_finished():
            positions.append(path.next_pos())
        self.assertEqual(positions, oracle)

    def test_jump_and_wait(self):
        """
        Check basic movement of cursor works.
        """
        path = Path()
        path.jump_to(10, 10)
        path.wait(3)
        self.assert_path_equals(path, [(10, 10), (10, 10), (10, 10), (10, 10)])

    def test_straight_lines(self):
        """
        Check a path works in straight lines.
        """
        # Horizontal
        path = Path()
        path.jump_to(10, 10)
        path.move_straight_to(15, 10, 5)
        self.assert_path_equals(
            path,
            [(10, 10), (11, 10), (12, 10), (13, 10), (14, 10), (15, 10)])

        # Vertical
        path = Path()
        path.jump_to(5, 5)
        path.move_straight_to(5, 10, 5)
        self.assert_path_equals(
            path,
            [(5, 5), (5, 6), (5, 7), (5, 8), (5, 9), (5, 10)])

        # Diagonal spaced
        path = Path()
        path.jump_to(5, 5)
        path.move_straight_to(15, 15, 5)
        self.assert_path_equals(
            path,
            [(5, 5), (7, 7), (9, 9), (11, 11), (13, 13), (15, 15)])

    def test_spline(self):
        """
        Check a path works with a spline curve.
        """
        path = Path()
        path.jump_to(0, 10)
        path.move_round_to([(0, 10), (20, 0), (40, 10), (20, 20), (0, 10)], 20)
        self.assert_path_equals(
            path,
            [(0, 10), (0, 10), (0, 10), (0, 10), (0, 10), (5, 7),
             (10, 4), (15, 1), (20, 0), (25, 1), (30, 3), (35, 7),
             (40, 10), (35, 12), (30, 16), (25, 18), (20, 20),  (15, 18),
             (10, 15), (5, 12), (0, 10)])

    def test_dynamic_path(self):
        """
        Check a dynamic path works as expected.
        """
        class TestPath(DynamicPath):
            def process_event(self, event):
                # Assume that we're always passing in a MouseEvent.
                self._x = event.x
                self._y = event.y

        # Initial path should start at specified location.
        path = TestPath(None, 0, 0)
        self.assertEqual(path.next_pos(), (0, 0))
        self.assertFalse(path.is_finished())

        # Process event should move location.
        path.process_event(MouseEvent(10, 5, 0))
        self.assertEqual(path.next_pos(), (10, 5))

        # Reset should return to original location.
        path.reset()
        self.assertEqual(path.next_pos(), (0, 0))


if __name__ == '__main__':
    unittest.main()



from __future__ import division
from pyfiglet import Figlet

from asciimatics.effects import Scroll, Mirage, Wipe, Cycle, Matrix, \
    BannerText, Stars, Print
from asciimatics.particles import DropScreen
from asciimatics.renderers import FigletText, SpeechBubble, Rainbow, Fire
from asciimatics.scene import Scene
from asciimatics.screen import Screen
from asciimatics.exceptions import ResizeScreenError
import sys


def _credits(screen):
    scenes = []

    text = Figlet(font="banner", width=200).renderText("ASCIIMATICS")
    width = max([len(x) for x in text.split("\n")])

    effects = [
        Print(screen,
              Fire(screen.height, 80, text, 0.4, 40, screen.colours),
              0,
              speed=1,
              transparent=False),
        Print(screen,
              FigletText("ASCIIMATICS", "banner"),
              screen.height - 9, x=(screen.width - width) // 2 + 1,
              colour=Screen.COLOUR_BLACK,
              bg=Screen.COLOUR_BLACK,
              speed=1),
        Print(screen,
              FigletText("ASCIIMATICS", "banner"),
              screen.height - 9,
              colour=Screen.COLOUR_WHITE,
              bg=Screen.COLOUR_WHITE,
              speed=1),
    ]
    scenes.append(Scene(effects, 100))

    effects = [
        Matrix(screen, stop_frame=200),
        Mirage(
            screen,
            FigletText("Asciimatics"),
            screen.height // 2 - 3,
            Screen.COLOUR_GREEN,
            start_frame=100,
            stop_frame=200),
        Wipe(screen, start_frame=150),
        Cycle(
            screen,
            FigletText("Asciimatics"),
            screen.height // 2 - 3,
            start_frame=200)
    ]
    scenes.append(Scene(effects, 250, clear=False))

    effects = [
        BannerText(
            screen,
            Rainbow(screen, FigletText(
                "Reliving the 80s in glorious ASCII text...", font='slant')),
            screen.height // 2 - 3,
            Screen.COLOUR_GREEN)
    ]
    scenes.append(Scene(effects))

    effects = [
        Mirage(
            screen,
            FigletText("Conceived and"),
            screen.height,
            Screen.COLOUR_GREEN),
        Mirage(
            screen,
            FigletText("written by:"),
            screen.height + 8,
            Screen.COLOUR_GREEN),
        Mirage(
            screen,
            FigletText("Peter Brittain"),
            screen.height + 16,
            Screen.COLOUR_GREEN),
        Scroll(screen, 3)
    ]
    scenes.append(Scene(effects, (screen.height + 24) * 3))

    effects = [
        Mirage(
            screen,
            FigletText("With help from:"),
            screen.height,
            Screen.COLOUR_GREEN),
        Mirage(
            screen,
            FigletText("Cory Benfield"),
            screen.height + 8,
            Screen.COLOUR_GREEN),
        Mirage(
            screen,
            FigletText("Bryce Guinta"),
            screen.height + 16,
            Screen.COLOUR_GREEN),
        Mirage(
            screen,
            FigletText("Aman Orazaev"),
            screen.height + 24,
            Screen.COLOUR_GREEN),
        Mirage(
            screen,
            FigletText("Daniel Kerr"),
            screen.height + 32,
            Screen.COLOUR_GREEN),
        Mirage(
            screen,
            FigletText("Dylan Janeke"),
            screen.height + 40,
            Screen.COLOUR_GREEN),
        Mirage(
            screen,
            FigletText("ianadeem"),
            screen.height + 48,
            Screen.COLOUR_GREEN),
        Mirage(
            screen,
            FigletText("Scott Mudge"),
            screen.height + 56,
            Screen.COLOUR_GREEN),
        Mirage(
            screen,
            FigletText("Luke Murphy"),
            screen.height + 64,
            Screen.COLOUR_GREEN),
        Mirage(
            screen,
            FigletText("mronkain"),
            screen.height + 72,
            Screen.COLOUR_GREEN),
        Scroll(screen, 3)
    ]
    scenes.append(Scene(effects, (screen.height + 80) * 3))

    effects = [
        Cycle(
            screen,
            FigletText("ASCIIMATICS", font='big'),
            screen.height // 2 - 8,
            stop_frame=100),
        Cycle(
            screen,
            FigletText("ROCKS!", font='big'),
            screen.height // 2 + 3,
            stop_frame=100),
        Stars(screen, (screen.width + screen.height) // 2, stop_frame=100),
        DropScreen(screen, 100, start_frame=100)
    ]
    scenes.append(Scene(effects, 200))

    effects = [
        Print(screen,
              SpeechBubble("Press 'X' to exit."), screen.height // 2 - 1, attr=Screen.A_BOLD)
    ]
    scenes.append(Scene(effects, -1))

    screen.play(scenes, stop_on_resize=True)


if __name__ == "__main__":
    while True:
        try:
            Screen.wrapper(_credits)
            sys.exit(0)
        except ResizeScreenError:
            pass



import unittest
from mock.mock import MagicMock
from asciimatics.particles import ShootScreen, DropScreen, Explosion, Rain, \
    StarFirework, PalmFirework, RingFirework, SerpentFirework
from asciimatics.screen import Screen, Canvas


class TestParticles(unittest.TestCase):
    def check_effect(self, canvas, effect, assert_fn,
                     is_blank=True, iterations=40, warm_up=0):
        """
        Basic checks for all effects.  Since they are all randomised to a
        certain extent, just check the overall content for expected values.
        """
        # Asciimatics always calls reset on entering a new Scene.
        effect.reset()

        # Check canvas is in desired starting state.
        if is_blank:
            for x in range(canvas.width):
                for y in range(canvas.height):
                    self.assertEqual(canvas.get_from(x, y), (32, 7, 0, 0))

        # Set up blank my_buffer - OK this should copy the existing screen, but
        # we just lose one iteration on the checks (when not really blank).
        my_buffer = [[(32, 7, 0, 0) for _ in range(40)] for _ in range(10)]

        # Re-draw comparing the my_buffer with what's on the canvas
        for i in range(iterations):
            effect.update(i)
            changed = False
            if i >= warm_up:
                view = ""
                for y in range(canvas.height):
                    for x in range(canvas.width):
                        value = canvas.get_from(x, y)
                        assert_fn(value)
                        if value != my_buffer[y][x]:
                            changed = True
                            my_buffer[y][x] = value
                        view += chr(value[0])
                    view += "\n"
                self.assertTrue(changed, "failed at step %d %s" % (i, view))

        # Check there is no stop frame by default.
        self.assertEqual(effect.stop_frame, 0)

    def test_shoot_screen(self):
        """
        Test that ShootScreen works as expected.
        """
        screen = MagicMock(spec=Screen, colours=8)
        canvas = Canvas(screen, 10, 40, 0, 0)
        canvas.centre("Hello World!", 5)
        effect = ShootScreen(canvas, canvas.width // 2, canvas.height // 2, 100)
        self.check_effect(canvas,
                          effect,
                          lambda value: self.assertIn(chr(value[0]),
                                                      'HeloWrd! '),
                          is_blank=False,
                          iterations=4)

    def test_drop_screen(self):
        """
        Test that DropScreen works as expected.
        """
        screen = MagicMock(spec=Screen, colours=8)
        canvas = Canvas(screen, 10, 40, 0, 0)
        canvas.centre("Hello World!", 0)
        effect = DropScreen(canvas, 100)
        self.check_effect(canvas,
                          effect,
                          lambda value: self.assertIn(chr(value[0]),
                                                      'HeloWrd! '),
                          is_blank=False,
                          warm_up=3,
                          iterations=10)

    def test_explosion(self):
        """
        Test that Explosion works as expected.
        """
        screen = MagicMock(spec=Screen, colours=8)
        canvas = Canvas(screen, 10, 40, 0, 0)
        effect = Explosion(canvas, 4, 4, 25)
        self.check_effect(canvas,
                          effect,
                          lambda value: self.assertIn(chr(value[0]), ' #'),
                          iterations=25)

    def test_rain(self):
        """
        Test that Rain works as expected.
        """
        screen = MagicMock(spec=Screen, colours=8)
        canvas = Canvas(screen, 10, 40, 0, 0)
        effect = Rain(canvas, 200)
        self.check_effect(canvas,
                          effect,
                          lambda value: self.assertIn(chr(value[0]), ' `\\v'))

    def test_star_firework(self):
        """
        Test that StarFirework works as expected.
        """
        screen = MagicMock(spec=Screen, colours=8)
        canvas = Canvas(screen, 10, 40, 0, 0)
        effect = StarFirework(canvas, 4, 4, 25)
        self.check_effect(canvas,
                          effect,
                          lambda value: self.assertIn(chr(value[0]), '|+:,. '),
                          iterations=25)

    def test_palm_firework(self):
        """
        Test that PalmFirework works as expected.
        """
        screen = MagicMock(spec=Screen, colours=8)
        canvas = Canvas(screen, 10, 40, 0, 0)
        effect = PalmFirework(canvas, 4, 4, 25)
        self.check_effect(canvas,
                          effect,
                          lambda value: self.assertIn(chr(value[0]), '|*+:,. '),
                          iterations=26)

    def test_ring_firework(self):
        """
        Test that RingFirework works as expected.
        """
        screen = MagicMock(spec=Screen, colours=8)
        canvas = Canvas(screen, 10, 40, 0, 0)
        effect = RingFirework(canvas, 4, 4, 25)
        self.check_effect(canvas,
                          effect,
                          lambda value: self.assertIn(chr(value[0]), '|*:. '),
                          iterations=15)

    def test_serpent_firework(self):
        """
        Test that SerpentFirework works as expected.
        """
        screen = MagicMock(spec=Screen, colours=8)
        canvas = Canvas(screen, 10, 40, 0, 0)
        effect = SerpentFirework(canvas, 4, 4, 25)
        self.check_effect(canvas,
                          effect,
                          lambda value: self.assertIn(chr(value[0]), '|+- '),
                          iterations=20)


if __name__ == '__main__':
    unittest.main()



from __future__ import division
from asciimatics.effects import Cog, Print
from asciimatics.renderers import FigletText
from asciimatics.scene import Scene
from asciimatics.screen import Screen
from asciimatics.exceptions import ResizeScreenError
import sys


def demo(screen):
    # Typical terminals are 80x24 on UNIX and 80x25 on Windows
    if screen.width != 80 or screen.height not in (24, 25):
        effects = [
            Print(screen, FigletText("Resize to 80x24"),
                  y=screen.height//2-3),
        ]
    else:
        effects = [
            Cog(screen, 20, 10, 10),
            Cog(screen, 60, 30, 15, direction=-1),
            Print(screen, FigletText("ascii", font="smkeyboard"),
                  attr=Screen.A_BOLD, x=47, y=3, start_frame=50),
            Print(screen, FigletText("matics", font="smkeyboard"),
                  attr=Screen.A_BOLD, x=45, y=7, start_frame=100),
            Print(screen, FigletText("by Peter Brittain", font="term"),
                  x=8, y=22, start_frame=150)
        ]
    screen.play([Scene(effects, -1)], stop_on_resize=True)


while True:
    try:
        Screen.wrapper(demo)
        sys.exit(0)
    except ResizeScreenError:
        pass



"""
A setuptools based setup module for asciimatics.

Based on the sample Python packages at:
https://packaging.python.org/en/latest/distributing.html
https://github.com/pypa/sampleproject
"""

from setuptools import setup, find_packages
from codecs import open
from os import path
import shutil

with open("./doc/source/conf_orig.py", "r") as src:
    with open("./doc/source/conf.py", "w") as dst:
        dst.write("# FILE COPIED FROM conf_orig.py; DO NOT CHANGE\n")
        shutil.copyfileobj(src, dst)

here = path.abspath(path.dirname(__file__))

# Get the long description from the relevant file and strip any pre-amble (i.e. badges) from it.
with open(path.join(here, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read().split("\n")
while long_description[0] not in ("ASCIIMATICS", "ASCIIMATICS\r"):
    long_description = long_description[1:]
long_description = "\n".join(long_description)

setup(
    name='asciimatics',
    use_scm_version={"write_to": "asciimatics/version.py"},
    description='A cross-platform package to replace curses (mouse/keyboard '
                'input & text colours/positioning) and create ASCII '
                'animations',
    long_description=long_description,
    url='https://github.com/peterbrittain/asciimatics',
    author='Peter Brittain',
    author_email='peter.brittain.os@gmail.com',
    license='Apache 2.0',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Console',
        'Environment :: Console :: Curses',
        'Intended Audience :: Developers',
        'Topic :: Text Processing :: General',
        'License :: OSI Approved :: Apache Software License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy',
        'Topic :: Software Development :: User Interfaces',
        'Topic :: Terminals',
    ],
    keywords='ascii ansi art credits titles animation curses '
             'ncurses windows xterm mouse keyboard terminal tty '
             'color colour crossplatform console',
    packages=find_packages(exclude=['contrib', 'docs', 'tests*']),
    install_requires=[
        'pyfiglet >= 0.7.2',
        'Pillow >= 2.7.0',
        'wcwidth',
        'future',
    ],
    extras_require={
        ':sys_platform == "win32"': ['pypiwin32'],
    },
    setup_requires=['setuptools_scm'],
    tests_require=[
        'mock',
        'nose',
    ],
    test_suite='nose.collector',
)



from asciimatics.effects import RandomNoise
from asciimatics.renderers import FigletText, Rainbow
from asciimatics.scene import Scene
from asciimatics.screen import Screen
from asciimatics.exceptions import ResizeScreenError
import sys


def demo(screen):
    effects = [
        RandomNoise(screen,
                    signal=Rainbow(screen,
                                   FigletText("ASCIIMATICS")))
    ]
    screen.play([Scene(effects, -1)], stop_on_resize=True)


while True:
    try:
        Screen.wrapper(demo)
        sys.exit(0)
    except ResizeScreenError:
        pass



"""
This module provides `Paths` to create animation effects with Sprites.  For more details see
http://asciimatics.readthedocs.io/en/latest/animation.html
"""
from __future__ import division
from __future__ import absolute_import
from __future__ import print_function
from __future__ import unicode_literals
from future.utils import with_metaclass
from abc import ABCMeta, abstractmethod
from builtins import object
from builtins import range


def _spline(t, p0, p1, p2, p3):
    """
    Catmull-Rom cubic spline to interpolate 4 given points.

    :param t: Time index through the spline (must be 0-1).
    :param p0: The previous point in the curve (for continuity).
    :param p1: The first point to interpolate.
    :param p2: The second point to interpolate.
    :param p3: The last point to interpolate.
    """
    return (
        t * ((2 - t) * t - 1) * p0 +
        (t * t * (3 * t - 5) + 2) * p1 +
        t * ((4 - 3 * t) * t + 1) * p2 +
        (t - 1) * t * t * p3) / 2


class _AbstractPath(with_metaclass(ABCMeta, object)):
    """
    Class to represent the motion of a Sprite.

    The Screen will reset() the Path before iterating through each position
    using next_pos() and checking whether it has reached the end using
    is_finished().
    """

    def __init__(self):
        """
        To define a Path, use the methods to jump to a location, wait or move
        between points.
        """
        self._steps = []
        self._index = None
        self._rec_x = 0
        self._rec_y = 0

    @abstractmethod
    def reset(self):
        """
        Reset the Path for use next time.
        """

    @abstractmethod
    def next_pos(self):
        """
        :return: The next position tuple (x, y) for the Sprite on this path.
        """

    @abstractmethod
    def is_finished(self):
        """
        :return: Whether this path has got to the end.
        """


class Path(_AbstractPath):
    """
    Class to record and play back the motion of a Sprite.

    The Screen will reset() the Path before iterating through each position
    using next_pos() and checking whether it has reached the end using
    is_finished().
    """

    def __init__(self):
        """
        To define a Path, use the methods to jump to a location, wait or move
        between points.
        """
        super(Path, self).__init__()
        self._steps = []
        self._index = 0
        self._rec_x = 0
        self._rec_y = 0
        self.reset()

    def reset(self):
        """
        Reset the Path for use next time.
        """
        self._index = 0

    def next_pos(self):
        """
        :return: The next position tuple (x, y) for the Sprite on this path.
        """
        result = None
        if self._index <= len(self._steps):
            result = self._steps[self._index]
            self._index += 1
        return result

    def is_finished(self):
        """
        :return: Whether this path has got to the end.
        """
        return self._index >= len(self._steps)

    def _add_step(self, pos):
        """
        Add a step to the end of the current recorded path.

        :param pos: The position tuple (x, y) to add to the list.
        """
        self._steps.append(pos)
        self._rec_x = pos[0]
        self._rec_y = pos[1]

    def wait(self, delay):
        """
        Wait at the current location for the specified number of iterations.

        :param delay: The time to wait (in animation frames).
        """
        for _ in range(0, delay):
            self._add_step((self._rec_x, self._rec_y))

    def jump_to(self, x, y):
        """
        Jump straight to the newly specified location - i.e. teleport there and
        don't create a path to get there.

        :param x:  X coord for the end position.
        :param y: Y coord for the end position.
        """
        self._add_step((x, y))

    def move_straight_to(self, x, y, steps):
        """
        Move straight to the newly specified location - i.e. create a straight
        line Path from the current location to the specified point.

        :param x:  X coord for the end position.
        :param y: Y coord for the end position.
        :param steps: How many steps to take for the move.
        """
        start_x = self._rec_x
        start_y = self._rec_y
        for i in range(1, steps + 1):
            self._add_step((
                int(start_x + (x - start_x) / float(steps) * i),
                int(start_y + (y - start_y) / float(steps) * i)))

    def move_round_to(self, points, steps):
        """
        Follow a path pre-defined by a set of at least 4 points.  This Path will
        interpolate the points into a curve and follow that curve.

        :param points: The list of points that defines the path.
        :param steps: The number of steps to take to follow the path.
        """
        # Spline interpolation needs a before and after point for the curve.
        # Duplicate the first and last points to handle this.  We also need
        # to move from the current position to the first specified point.
        points.insert(0, (self._rec_x, self._rec_y))
        points.insert(0, (self._rec_x, self._rec_y))
        points.append(points[-1])

        # Convert the points into an interpolated set of more detailed points.
        steps_per_spline = steps // (len(points) - 3)
        for j in range(1, len(points) - 2):
            for t in range(1, steps_per_spline + 1):
                y = _spline(float(t) / steps_per_spline,
                            float(points[j - 1][1]),
                            float(points[j][1]),
                            float(points[j + 1][1]),
                            float(points[j + 2][1]))
                x = int(points[j][0] + ((points[j + 1][0] - points[j][0]) *
                                        float(t) / steps_per_spline))
                self._add_step((x, int(y)))


class DynamicPath(with_metaclass(ABCMeta, _AbstractPath)):
    """
    Class to create a dynamic path that reacts to events

    The Screen will reset() the Path before iterating through each position
    using next_pos() and checking whether it has reached the end using
    is_finished().
    """

    def __init__(self, screen, x, y):
        """
        To implement a DynamicPath, override the :py:meth:`.process_event()`
        method to react to any user input.
        """
        super(DynamicPath, self).__init__()
        self._screen = screen
        self._x = self._start_x = x
        self._y = self._start_y = y
        self.reset()

    def reset(self):
        """
        Reset the Path for use next time.
        """
        self._x = self._start_x
        self._y = self._start_y

    def next_pos(self):
        """
        :return: The next position tuple (x, y) for the Sprite on this path.
        """
        return self._x, self._y

    def is_finished(self):
        """
        :return: Whether this path has got to the end.
        """
        return False

    @abstractmethod
    def process_event(self, event):
        """
        Process any mouse event.

        :param event: The event that was triggered.
        :returns: None if the Effect processed the event, else the original
                  event.
        """



from asciimatics.effects import Print
from asciimatics.renderers import BarChart, FigletText
from asciimatics.scene import Scene
from asciimatics.screen import Screen
from asciimatics.exceptions import ResizeScreenError
import sys
import math
import time
from random import randint


def fn():
    return randint(0, 40)


def wv(x):
    return lambda: 1 + math.sin(math.pi * (2*time.time()+x) / 5)


def demo(screen):
    scenes = []
    if screen.width != 132 or screen.height != 24:
        effects = [
            Print(screen, FigletText("Resize to 132x24"),
                  y=screen.height//2-3),
        ]
    else:
        effects = [
            Print(screen,
                  BarChart(10, 40, [fn, fn],
                           char="=",
                           gradient=[(20, Screen.COLOUR_GREEN),
                                     (30, Screen.COLOUR_YELLOW),
                                     (40, Screen.COLOUR_RED)]),
                  x=13, y=1, transparent=False, speed=2),
            Print(screen,
                  BarChart(
                      13, 60,
                      [wv(1), wv(2), wv(3), wv(4), wv(5), wv(7), wv(8), wv(9)],
                      colour=Screen.COLOUR_GREEN,
                      axes=BarChart.BOTH,
                      scale=2.0),
                  x=68, y=1, transparent=False, speed=2),
            Print(screen,
                  BarChart(
                      7, 60, [lambda: time.time() * 10 % 101],
                      gradient=[
                          (33, Screen.COLOUR_RED, Screen.COLOUR_RED),
                          (66, Screen.COLOUR_YELLOW, Screen.COLOUR_YELLOW),
                          (100, Screen.COLOUR_WHITE, Screen.COLOUR_WHITE),
                      ] if screen.colours < 256 else [
                          (10, 234, 234), (20, 236, 236), (30, 238, 238),
                          (40, 240, 240), (50, 242, 242), (60, 244, 244),
                          (70, 246, 246), (80, 248, 248), (90, 250, 250),
                          (100, 252, 252)
                      ],
                      char=">",
                      scale=100.0,
                      labels=True,
                      axes=BarChart.X_AXIS),
                  x=68, y=16, transparent=False, speed=2),
            Print(screen,
                  BarChart(
                      10, 60,
                      [wv(1), wv(2), wv(3), wv(4), wv(5), wv(7), wv(8), wv(9)],
                      colour=[c for c in range(1, 8)],
                      bg=[c for c in range(1, 8)],
                      scale=2.0,
                      axes=BarChart.X_AXIS,
                      intervals=0.5,
                      labels=True,
                      border=False),
                  x=3, y=13, transparent=False, speed=2)
        ]

    scenes.append(Scene(effects, -1))
    screen.play(scenes, stop_on_resize=True)


while True:
    try:
        Screen.wrapper(demo)
        sys.exit(0)
    except ResizeScreenError:
        pass



# -*- coding: utf-8 -*-
from __future__ import division
from __future__ import absolute_import
from __future__ import print_function
from __future__ import unicode_literals
from datetime import datetime
import time
import unittest
from asciimatics.utilities import readable_mem, readable_timestamp


class TestWidgets(unittest.TestCase):

    def test_readable_mem(self):
        """
        Check readable_mem works as expected.
        """
        # Check formatting works as expected.
        self.assertEquals("9999", readable_mem(9999))
        self.assertEquals("10K", readable_mem(10240))
        self.assertEquals("1024K", readable_mem(1024*1024))
        self.assertEquals("10M", readable_mem(1024*1024*10))
        self.assertEquals("10G", readable_mem(1024*1024*1024*10))
        self.assertEquals("10T", readable_mem(1024*1024*1024*1024*10))
        self.assertEquals("10P", readable_mem(1024*1024*1024*1024*1024*10))

    def test_readable_timestamp(self):
        """
        Check readable_timestamp works as expected.
        """
        # Check formatting works as expected.
        self.assertEquals("12:01:02AM", readable_timestamp(
            time.mktime(datetime.now().replace(hour=0, minute=1, second=2).timetuple())))
        self.assertEquals("1999-01-02", readable_timestamp(
            time.mktime(datetime.now().replace(year=1999, month=1, day=2).timetuple())))
